VERSION = '0.2.1'
VERSION_COPY = f'''\
Copyright (C) 2023 Marco Bonelli
Licensed under the GNU General Public License v3.0
'''
VERSION_HELP = f'''\
Systrack version {VERSION}
{VERSION_COPY}\
'''

if __name__ == '__main__':
	print(VERSION)
